@@ -17,6 +17,22 @@ __date__ = '2017-02-15'
 __updated__ = '2018-02-23'
 
 
+def handle_prep_mergemask(args, configs):
+    """Handle `prep mergemask`
+
+    :param args: parsed arguments
+    :type args: :py:class:`argparse.Namespace`
+    :param configs: configurations object
+    :type configs: :py:class:`sfftk.core.configs.Configs`
+    :return exit_status: exit status
+    :rtype exit_status: int
+    """
+    if all(map(lambda mask: re.search(r'.*\.(map|mrc|rec)$', mask, re.IGNORECASE), args.masks)):
+        from .core.prep import mergemask
+        return mergemask(args, configs)
+    return 65
+
+
 def handle_prep(args, configs):
     """Handle `prep` subcommand
 
@@ -27,15 +43,22 @@ def handle_prep(args, configs):
     :return exit_status: exit status
     :rtype exit_status: int
     """
-    if re.match(r'.*\.(map|mrc|rec)$', args.from_file, re.IGNORECASE):
-        from .core.prep import bin_map
-        return bin_map(args, configs)
-    elif re.match(r'.*\.(stl)$', args.from_file, re.IGNORECASE):
-        from .core.prep import transform
-        return transform(args, configs)
-    else:
-        print_date("No prep protocol for file type {}".format(args.from_file))
-        return 65
+    if args.prep_subcommand == 'binmap':
+        if re.match(r'.*\.(map|mrc|rec)$', args.from_file, re.IGNORECASE):
+            from .core.prep import bin_map
+            return bin_map(args, configs)
+        else:
+            print_date("No prep protocol for file type {}".format(args.from_file))
+            return 65
+    elif args.prep_subcommand == 'transform':
+        if re.match(r'.*\.(stl)$', args.from_file, re.IGNORECASE):
+            from .core.prep import transform
+            return transform(args, configs)
+        else:
+            print_date("No prep protocol for file type {}".format(args.from_file))
+            return 65
+    elif args.prep_subcommand == 'mergemask':
+        return handle_prep_mergemask(args, configs)
 
 
 def handle_convert(args, configs):  # @UnusedVariable
@@ -62,8 +85,8 @@ def handle_convert(args, configs):  # @UnusedVariable
     except (ValueError, KeyError):
         if args.multi_file:
             if re.match(r'.*\.(map|mrc|rec)$', args.from_file[0], re.IGNORECASE):
-                from .formats.map import MapSegmentation
-                seg = MapSegmentation(args.from_file)
+                from .formats.map import BinaryMaskSegmentation
+                seg = BinaryMaskSegmentation(args.from_file)
             elif re.match(r'.*\.stl$', args.from_file[0], re.IGNORECASE):
                 from .formats.stl import STLSegmentation
                 seg = STLSegmentation(args.from_file)
@@ -90,8 +113,12 @@ def handle_convert(args, configs):  # @UnusedVariable
                 from .formats.am import AmiraMeshSegmentation
                 seg = AmiraMeshSegmentation(args.from_file)
             elif re.match(r'.*\.(map|mrc|rec)$', args.from_file, re.IGNORECASE):
-                from .formats.map import MapSegmentation
-                seg = MapSegmentation([args.from_file])
+                if args.label_tree is not None:  # merged mask
+                    from .formats.map import MergedMaskSegmentation
+                    seg = MergedMaskSegmentation(args.from_file, label_tree=args.label_tree)
+                else:  # single binary mask
+                    from .formats.map import BinaryMaskSegmentation
+                    seg = BinaryMaskSegmentation([args.from_file])
             elif re.match(r'.*\.stl$', args.from_file, re.IGNORECASE):
                 from .formats.stl import STLSegmentation
                 seg = STLSegmentation([args.from_file])
@@ -117,7 +144,8 @@ def handle_convert(args, configs):  # @UnusedVariable
         if args.image:
             from .readers.mapreader import compute_transform
             transform = compute_transform(args.image)
-        sff_seg = seg.convert(details=args.details, verbose=args.verbose, transform=transform)  # convert according to args
+        sff_seg = seg.convert(details=args.details, verbose=args.verbose,
+                              transform=transform)  # convert according to args
         # export as args.format
         if args.verbose:
             print_date("Exporting to {}".format(args.output))
@@ -454,6 +482,7 @@ def handle_view(args, configs):  # @UnusedVariable
                     print_date("Print type: numpy arrray (use -h/--help for other formats)")
                     print(transform)
             else:  # we're dealing with a mask/segmentation
+                # todo: replace with BinaryMaskSegmentation
                 from .formats.map import MapSegmentation
                 seg = MapSegmentation([args.from_file], header_only=True)
                 print("*" * 50)
@@ -585,8 +614,8 @@ def main():
         from .core.parser import parse_args
         args, configs = parse_args(sys.argv[1:])
         # missing args
-        if args == 64:
-            return 64
+        if args != 0 and isinstance(args, int):
+            return args
         elif args == 0:  # e.g. show version has no error but has no handler either
             return 0
         # subcommands
